@@ -4,7 +4,6 @@
 import os
 import re
 import sys
-import cairosvg
 from getopt import getopt
 try:
     from JsonToMarkdown import preprocess
@@ -15,6 +14,7 @@ except ImportError:
     import libsvg
     import libmd
 
+__version__ = 'v1.1.7'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook):
@@ -34,6 +34,7 @@ class TranslateJson(object):
         self.history_group = {}
         self.pre_group = ''
         self.all_reg_data = ''
+        self.all_reg_tex_data = ''
         self.all_reg_list = []
         self.reg_data = ''
         self.path_addr_dict = {}
@@ -394,7 +395,7 @@ class TranslateJson(object):
         #table_title = 'Register:' + name + ' ('  + addr + ')'
         reg_addr_msg = 'address : '  + addr
         reg_hex_reset = 'reset_value : ' + hex_reset
-        register_data = "# " + name + "\n" + reg_addr_msg + '<br>' + \
+        register_data = "# " + name + "\n\n" + reg_addr_msg + '<br>' + \
                 reg_hex_reset + '\n' + register_data
         if self.output_md:
             os.system("mv " + svg_name + " " + self.markdownpath)
@@ -444,6 +445,8 @@ class TranslateJson(object):
         for i in self.all_reg_list:
             self.all_reg_data += lm.md_create_body_line([i['name'], i['addr'], \
                     i['reset'], i['des']], self.output_md)
+            self.all_reg_tex_data += lm.tex_create_body_line([i['name'], i['addr'], \
+                    i['reset'], i['des']], self.gitbookpath)
 
     def main(self):
         file_msg = os.path.basename(self.js_file).split(".json")[0]
@@ -452,6 +455,7 @@ class TranslateJson(object):
         self.js_dpath = self.get_dpath(self.js_dict)
         lm = libmd.LibMarkdown()
         self.all_reg_data = lm.md_create_title_line(['名称', '地址', '初值', '描述'])
+        self.all_reg_tex_data = lm.md_create_title_line(['名称', '地址', '初值', '描述'])
         if self.output_gitbook:
             if self.dir_type == "alone":
                 self.gitbookpath = os.path.join("_json_output/gitbook/", file_msg)
@@ -476,7 +480,7 @@ class TranslateJson(object):
                             fd.write('  * [' + name + ']('+ name + '.md)\n')
                             self.create_md3(self.js_dpath[i], lm)
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
-                        fc.write("## " + file_msg + "寄存器列表\n" + self.all_reg_data)
+                        fc.write("## " + file_msg + "寄存器列表\n\n" + self.all_reg_data)
                 print("\n\tcreate " + self.gitbookpath +" success") 
             elif self.dir_type == "link":
                 self.gitbookpath = os.path.join(self.link_path, "_json_output/", file_msg)
@@ -508,7 +512,9 @@ class TranslateJson(object):
                     self.relist(self.all_reg_list)
                     self.create_all_reg_data(lm)
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
-                        fc.write("## " + file_msg + "寄存器列表\n" + self.all_reg_data)
+                        fc.write("## " + file_msg + "寄存器列表\n\n" + self.all_reg_data)
+                    with open(os.path.join(self.gitbookpath, 'all_register_tex.md'), 'w') as fc:
+                        fc.write("## " + file_msg + "寄存器列表\n\n" + self.all_reg_tex_data)
                     with open(os.path.join(self.gitbookpath, 'detail.md'), 'w') as fc:
                         fc.write(self.reg_data)
                 self.check_file('README.md')
@@ -550,7 +556,7 @@ def main():
     if len(sys.argv) <= 1:
             usage()
             sys.exit()
-    opts,args = getopt(sys.argv[1:],"f:l:gh")
+    opts,args = getopt(sys.argv[1:],"f:l:ghv")
     js_file = "demo.json"
     link_path = ''
     output_md = 1
@@ -570,6 +576,9 @@ def main():
         if k == "-h":
             usage()
             sys.exit()
+        if k == "-v":
+            print(__version__)
+            sys.exit()
     #print("opts:", opts, "args", args)
     tj = TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook)
     tj.main()
